Crate iso3166_1

Crate iso3166_1 

Structs

CountryCode
Struct that contains the data for each Country Code defined by ISO 3166-1, including the following pieces of information:

Functions

all
Returns a Vec of all CountryCodes defined by ISO 3166-1.
alpha2
Returns an Option of a CountryCode with the given alpha2 code.
alpha3
Returns an Option of a CountryCode with the given alpha3 code.
name
Returns an Option of a CountryCode with the given name.
num
Returns an Option of a CountryCode with the given numeric value.
num_range
Returns a Vec of CountryCodes that have a numeric value within the range of the from and to given. The from and to are optional, and can either be None or Some(&str) for variations of the range wanted.